<?php
// Version: 1.1; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '1.1';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = false;

	/* Show sticky and lock status seperate from topic icons? */
	$settings['seperate_sticky_lock'] = true;
}

// The main sub template above the content.
function template_main_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title'], '" />', empty($context['robot_no_index']) ? '' : '
	<meta name="robots" content="noindex" />', '
	<meta name="keywords" content="PHP, MySQL, bulletin, board, free, open, source, smf, simple, machines, forum" />
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/script.js?fin11"></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_lang_images_url = "', $settings['images_url'], '/' . $context['user']['language'] . '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";
	// ]]></script>
	<title>', $context['page_title'], '</title>';
	
	// The ?fin11 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style.css?fin11" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/print.css?fin11" media="print" />';

	/* Internet Explorer 4/5 and Opera 6 just don't do font sizes properly. (they are big...)
		Thus, in Internet Explorer 4, 5, and Opera 6 this will show fonts one size smaller than usual.
		Note that this is affected by whether IE 6 is in standards compliance mode.. if not, it will also be big.
		Standards compliance mode happens when you use xhtml... */
	if ($context['browser']['needs_size_fix'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/fonts-compat.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" target="_blank" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="' . $scripturl . '?board=' . $context['current_board'] . '.0" />';

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			var current_leftbar = ', empty($options['collapse_leftbar']) ? 'false' : 'true', ';
			function shrinkHeaderLeftbar(mode)
		{';
	// Guests don't have theme options!!
	if ($context['user']['is_guest'])
		echo '
			document.cookie = "upshrink=" + (mode ? 1 : 0);';
	else
		echo '
			smf_setThemeOption("collapse_leftbar", mode ? 1 : 0, null, "', $context['session_id'], '");';
		echo '
			document.getElementById("upshrinkLeftbar").src = smf_images_url + (mode ? "/upshrink2.gif" : "/upshrink.gif");
			document.getElementById("leftbarHeader").style.display = mode ? "none" : "";
			current_leftbar = mode;
		}
		// ]]></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			var current_rightbar = ', empty($options['collapse_rightbar']) ? 'false' : 'true', ';
			function shrinkHeaderRightbar(mode)
		{';
	// Guests don't have theme options!!
	if ($context['user']['is_guest'])
		echo '
			document.cookie = "upshrink=" + (mode ? 1 : 0);';
	else
		echo '
			smf_setThemeOption("collapse_rightbar", mode ? 1 : 0, null, "', $context['session_id'], '");';
		echo '
			document.getElementById("upshrinkRightbar").src = smf_images_url + (mode ? "/upshrink2.gif" : "/upshrink.gif");
			document.getElementById("rightbarHeader").style.display = mode ? "none" : "";
			current_rightbar = mode;
		}
		// ]]></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var current_header = ', empty($options['collapse_header']) ? 'false' : 'true', ';

		function shrinkHeader(mode)
		{';

	// Guests don't have theme options!!
	if ($context['user']['is_guest'])
		echo '
			document.cookie = "upshrink=" + (mode ? 1 : 0);';
	else
		echo '
			smf_setThemeOption("collapse_header", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
			document.getElementById("upshrink").src = smf_images_url + (mode ? "/upshrink2.gif" : "/upshrink.gif");

			document.getElementById("upshrinkHeader").style.display = mode ? "none" : "";
			document.getElementById("upshrinkHeader2").style.display = mode ? "none" : "";

			current_header = mode;
		}
	// ]]></script>';
	echo '
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			function smfLangHighlight(element, value)
			{
				element.src = smf_lang_images_url + "/" + (value ? "h_" : "") + element.id + ".gif";
			}
		// ]]></script>';
	// the routine for the info center upshrink
	echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			var current_header_ic = ', empty($options['collapse_header_ic']) ? 'false' : 'true', ';
			function shrinkHeaderIC(mode)
			{';
	if ($context['user']['is_guest'])
		echo '
				document.cookie = "upshrinkIC=" + (mode ? 1 : 0);';
	else
		echo '
				smf_setThemeOption("collapse_header_ic", mode ? 1 : 0, null, "', $context['session_id'], '");';
	echo '
				document.getElementById("upshrink_ic").src = smf_images_url + (mode ? "/expand.gif" : "/collapse.gif");
				document.getElementById("upshrinkHeaderIC").style.display = mode ? "none" : "";
				current_header_ic = mode;
			}
		// ]]></script>
</head>
<body>';
	// TinyPortal start
	if(!empty($settings['use_tp']) && $context['TPortal']['fixed_width']!=0)
		echo '<table align="center" width="'.$context['TPortal']['fixed_width'].'" cellpadding="0" cellspacing="0" border="0"><tr><td>';
	// TinyPortal end
	echo '
	<div ', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? ' style="width: 100%;"' : '', '>
		<table border="0" width="100%" cellspacing="0" cellpadding="0">
			<tr>
				<td width="150" class="catbg_top_left">&nbsp;</td>
				<td class="catbg_top_middle" style="text-align: center;vertical-align: top;padding-top: 4px;"><img src="', $settings['images_url'], '/sml_apple.gif" alt="small apple" /></td>
				<td class="catbg_top_right" width="150" style="text-align: right;vertical-align: top;padding-top: 8px;padding-right: 5px;"><img src="', $settings['images_url'], '/minimize.gif" alt="minimize" /></td>
			</tr>
		</table>
		<table width="100%" cellpadding="0" cellspacing="0" border="0">
			<tr>
				<td class="catbg_h" height="32" align="left">';

	if (empty($settings['header_logo_url']))
		echo '
					<span style="font-family: Verdana, sans-serif; font-size: 140%; ">', $context['forum_name'], '</span>';
	else
		echo '
					<img src="', $settings['header_logo_url'], '" style="margin: 4px;" alt="', $context['forum_name'], '" />';

	echo '
				</td>
			</tr>
		</table>';
	// TinyPortal
	if ((!empty($settings['use_tp']) && $context['TPortal']['showtop'] == 1) || !isset($context['TPortal']))
	{
	// TinyPortal end
	// display user name
	echo '
		<table width="100%" cellpadding="0" cellspacing="0" border="0">
			<tr>';

	if($context['user']['is_logged'])
		echo '
				<td class="titlebg2_l" height="32">
					<span> ', $txt['hello_member_ndt'], ' <b>', $context['user']['name'] , '</b></span>
				</td>';
	else
		echo ' <td class="titlebg2_l" height="32">&nbsp;</td>';

	// display the time
	echo '
				<td class="titlebg2_r" height="32" align="right">
					<span class="smalltext">' , $context['current_time'], '</span>';

	// this is the upshrink button for the user info section
	echo '
					<a href="#" onclick="shrinkHeader(!current_header); return false;"><img id="upshrink" src="', $settings['images_url'], '/', empty($options['collapse_header']) ? 'upshrink.gif' : 'upshrink2.gif', '" alt="*" title="', $txt['upshrink_description'], '" align="bottom" style="margin: 0 1ex;" /></a>
				</td>
			</tr>
			<tr id="upshrinkHeader"', empty($options['collapse_header']) ? '' : ' style="display: none;"', '>
				<td valign="top" colspan="2">
					<table width="100%" cellpadding="8" cellspacing="0" border="0">
						<tr>';

	if (!empty($context['user']['avatar']))
		echo '
							<td class="windowbg_l" valign="middle">', $context['user']['avatar']['image'], '</td>';
	else
		echo '
							<td class="windowbg_l" valign="middle">&nbsp;</td>';

	echo '
							<td colspan="2" width="100%" valign="top" class="windowbg2_r"><span class="middletext">';

	// If the user is logged in, display stuff like their name, new messages, etc.
	if ($context['user']['is_logged'])
	{
		echo '
			', $context['allow_pm'] ? '' . $txt[152] . ' <a href="' . $scripturl . '?action=pm">' . $context['user']['messages'] . ' ' . ($context['user']['messages'] != 1 ? $txt[153] : $txt[471]) . '</a>' . $txt['newmessages4'] . ' ' . $context['user']['unread_messages'] . ' ' . ($context['user']['unread_messages'] == 1 ? $txt['newmessages0'] : $txt['newmessages1']).'' : '<br />', '.<br />
			<a href="', $scripturl, '?action=unread">', $txt['unread_since_visit'], '</a> <br />
			<a href="', $scripturl, '?action=unreadreplies">', $txt['show_unread_replies'], '</a><br />';

	}
	// Otherwise they're a guest - send them a lovely greeting...
	else
		echo $txt['welcome_guest'];

	// Now, onto our second set of info, are they logged in again?
	if ($context['user']['is_logged'])
	{
		// Is the forum in maintenance mode?
		if ($context['in_maintenance'] && $context['user']['is_admin'])
			echo '
								<b>', $txt[616], '</b><br />';

		// Are there any members waiting for approval?
		if (!empty($context['unapproved_members']))
			echo '
								', $context['unapproved_members'] == 1 ? $txt['approve_thereis'] : $txt['approve_thereare'], ' <a href="', $scripturl, '?action=viewmembers;sa=browse;type=approve">', $context['unapproved_members'] == 1 ? $txt['approve_member'] : $context['unapproved_members'] . ' ' . $txt['approve_members'], '</a> ', $txt['approve_members_waiting'], '<br />';

		// Show the total time logged in?
		if (!empty($context['user']['total_time_logged_in']))
		{
			echo '
								', $txt['totalTimeLogged1'];

			// If days is just zero, don't bother to show it.
			if ($context['user']['total_time_logged_in']['days'] > 0)
				echo $context['user']['total_time_logged_in']['days'] . $txt['totalTimeLogged2'];

			// Same with hours - only show it if it's above zero.
			if ($context['user']['total_time_logged_in']['hours'] > 0)
				echo $context['user']['total_time_logged_in']['hours'] . $txt['totalTimeLogged3'];

			// But, let's always show minutes - Time wasted here: 0 minutes ;).
			echo $context['user']['total_time_logged_in']['minutes'], $txt['totalTimeLogged4'], '<br />';
		}
		echo '				</span>';
	}
	// Otherwise they're a guest - this time ask them to either register or login - lazy bums...
	else
	{
		echo '				</span>
								<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/sha1.js"></script>

								<form action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '" class="middletext" style="margin: 3px 1ex 1px 0;"', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>
									<input type="text" name="user" size="10" /> <input type="password" name="passwrd" size="10" />
									<select name="cookielength">
										<option value="60">', $txt['smf53'], '</option>
										<option value="1440">', $txt['smf47'], '</option>
										<option value="10080">', $txt['smf48'], '</option>
										<option value="43200">', $txt['smf49'], '</option>
										<option value="-1" selected="selected">', $txt['smf50'], '</option>
									</select>
									<input type="submit" value="', $txt[34], '" /><br />
									<span class="middletext">', $txt['smf52'], '</span>
									<input type="hidden" name="hash_passwrd" value="" />
								</form>';
	}

	echo '
							</td>
						</tr>
					</table>
				</td>
			</tr>
		</table>';

	echo '
		<table id="upshrinkHeader2"', empty($options['collapse_header']) ? '' : ' style="display: none;"', ' width="100%" cellpadding="4" cellspacing="0" border="0">
			<tr>';

	// Show a random news item? (or you could pick one from news_lines...)
	if (!empty($settings['enable_news']))
		echo '
				<td width="90%" class="titlebg2_l">
					<span class="smalltext"><b>', $txt[102], '</b>: ', $context['random_news_line'], '</span>
				</td>';
	echo '
				<td class="titlebg2_r" align="right" nowrap="nowrap" >
					<form action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '" style="margin: 0;">
						<a href="', $scripturl, '?action=search;advanced"><img src="'.$settings['images_url'].'/filter.gif" align="middle" alt="', $txt[182], '" /></a>
						<input type="text" name="search" value="" style="width: 190px;" />&nbsp;
						<input type="submit" name="submit" value="', $txt[182], '" style="width: 11ex;" />
						<input type="hidden" name="advanced" value="0" />';

	// Search within current topic?
	if (!empty($context['current_topic']))
		echo '
						<input type="hidden" name="topic" value="', $context['current_topic'], '" />';

		// If we're on a certain board, limit it to this board ;).
	elseif (!empty($context['current_board']))
		echo '
						<input type="hidden" name="brd[', $context['current_board'], ']" value="', $context['current_board'], '" />';

	echo '
					</form>
				</td>
			</tr>
		</table>';
	// TinyPortal
	}
	//  end
	echo '</div>';
	// Show the menu here, according to the menu sub template.
	echo '
		<div ', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? 'style="width: 100%;"' : '', '>
			<table border="0" width="100%" cellspacing="0" cellpadding="0">
				<tr>
					<td class="catbg_bottom_left" width="15"></td>
					<td class="catbg_bottom_middle">' , template_menu() , '</td>
					<td class="catbg_bottom_right" width="15"></td>
				</tr>
			</table>
	</div>';
	checkmods();
	// The main content should go here.  A table is used because IE 6 just can't handle a div.
	echo '
	<table width="100%" cellpadding="0" cellspacing="0" border="0"><tr>';
	// TinyPortal integrated bars
	if(!empty($settings['use_tp']) && $context['TPortal']['leftbar']) {
		echo '<td width="' ,$context['TPortal']['leftbar_width'], '" style="padding: ' , isset($context['TPortal']['padding']) ? $context['TPortal']['padding'] : '4' , 'px; padding-top: 4px;padding-right: 1ex;" valign="top">
			<div id="leftbarHeader"', empty($options['collapse_leftbar']) ? '' : ' style="display: none;"', ' style="padding-top: 5px; width: ' ,$context['TPortal']['leftbar_width'], 'px;">';
			TPortal_sidebar('left');
		echo '</div></td>';
	}
		echo '<td width="100%" align="left" valign="top" style="padding-top: 10px; padding-bottom: 10px;">';
	if(!empty($settings['use_tp']) && $context['TPortal']['centerbar'])
		echo '<div>' , TPortal_sidebar('center') , '</div>';
}

function template_main_below()
{
	global $context, $settings, $options, $scripturl, $txt;

	echo '</td>';
	// TinyPortal integrated bars
	if(!empty($settings['use_tp']) && $context['TPortal']['rightbar']){
	echo '<td style="padding: ' , isset($context['TPortal']['padding']) ? $context['TPortal']['padding'] : '4' , 'px; padding-top: 4px; padding-left: 1ex;" valign="top" align="right">
		<div id="rightbarHeader"', empty($options['collapse_rightbar']) ? '' : ' style="display: none;"', ' style="width: ' ,$context['TPortal']['rightbar_width'], 'px; text-align: left; padding-top: 5px;">';
		TPortal_rightbar();
	echo '</div></td>';
	}
	echo '</tr></table>';

	// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
	echo '

	<div id="footerarea" style="text-align: center; padding-bottom: 1ex;', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? ' width: 100%;' : '', '">
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			function smfFooterHighlight(element, value)
			{
				element.src = smf_images_url + "/" + (value ? "h_" : "") + element.id + ".gif";
			}
		// ]]></script>
		<table cellspacing="0" cellpadding="0" border="0" align="center" width="100%">
			<tr>
				<td width="28%" valign="middle" align="', !$context['right_to_left'] ? 'right' : 'left', '">
					<a href="http://www.mysql.com/" target="_blank"><img id="powered-mysql" src="', $settings['images_url'], '/powered-mysql.gif" alt="', $txt['powered_by_mysql'], '" width="54" height="20" style="margin: 5px 16px;" onmouseover="smfFooterHighlight(this, true);" onmouseout="smfFooterHighlight(this, false);" /></a>
					<a href="http://www.php.net/" target="_blank"><img id="powered-php" src="', $settings['images_url'], '/powered-php.gif" alt="', $txt['powered_by_php'], '" width="54" height="20" style="margin: 5px 16px;" onmouseover="smfFooterHighlight(this, true);" onmouseout="smfFooterHighlight(this, false);" /></a>
				</td>
				<td valign="middle" align="center" class="smalltext" style="white-space: nowrap;">
					', theme_copyright(), '<br />', !empty($settings['use_tp']) ? '' . tportal_version() . '' : '' ,'<br />
					Apple and the Apple logo are trademarks of <a href="http://www.apple.com" target="_blank">Apple Inc</a>. &copy; 2007<br />
					:: Faux Apple theme by <a target="_blank" href="http://www.rumbaar.net">Rumbaar</a> ::
				</td>
				<td width="28%" valign="middle" align="', !$context['right_to_left'] ? 'left' : 'right', '">';
				if(empty($settings['use_tp']))
					echo '<a href="http://validator.w3.org/check/referer" target="_blank"><img id="valid-xhtml10" src="', $settings['images_url'], '/valid-xhtml10.gif" alt="', $txt['valid_xhtml'], '" width="54" height="20" style="margin: 5px 16px;" onmouseover="smfFooterHighlight(this, true);" onmouseout="smfFooterHighlight(this, false);" /></a>';
				echo'
					<a href="http://jigsaw.w3.org/css-validator/check/referer" target="_blank"><img id="valid-css" src="', $settings['images_url'], '/valid-css.gif" alt="', $txt['valid_css'], '" width="54" height="20" style="margin: 5px 16px;" onmouseover="smfFooterHighlight(this, true);" onmouseout="smfFooterHighlight(this, false);" /></a>
				</td>
			</tr>
		</table>';

		// Show the load time?
	if ($context['show_load_time'])
		echo '
		<span class="smalltext">', $txt['smf301'], $context['load_time'], $txt['smf302'], $context['load_queries'], $txt['smf302b'], '</span>';

	// This is an interesting bug in Internet Explorer AND Safari. Rather annoying, it makes overflows just not tall enough.
	if (($context['browser']['is_ie'] && !$context['browser']['is_ie4']) || $context['browser']['is_mac_ie'] || $context['browser']['is_safari'] || $context['browser']['is_firefox'])
	{
		// The purpose of this code is to fix the height of overflow: auto div blocks, because IE can't figure it out for itself.
		echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[';

		// Unfortunately, Safari does not have a "getComputedStyle" implementation yet, so we have to just do it to code...
		if ($context['browser']['is_safari'])
			echo '
			window.addEventListener("load", smf_codeFix, false);

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if ((codeFix[i].className == "code" || codeFix[i].className == "post" || codeFix[i].className == "signature") && codeFix[i].offsetHeight < 20)
						codeFix[i].style.height = (codeFix[i].offsetHeight + 20) + "px";
				}
			}';
		elseif ($context['browser']['is_firefox'])
			echo '
			window.addEventListener("load", smf_codeFix, false);
			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if (codeFix[i].className == "code" && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0))
						codeFix[i].style.overflow = "scroll";
				}
			}';			
		else
			echo '
			var window_oldOnload = window.onload;
			window.onload = smf_codeFix;

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = codeFix.length - 1; i > 0; i--)
				{
					if (codeFix[i].currentStyle.overflow == "auto" && (codeFix[i].currentStyle.height == "" || codeFix[i].currentStyle.height == "auto") && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0) && (codeFix[i].offsetHeight != 0 || codeFix[i].className == "code"))
						codeFix[i].style.height = (codeFix[i].offsetHeight + 36) + "px";
				}

				if (window_oldOnload)
				{
					window_oldOnload();
					window_oldOnload = null;
				}
			}';

		echo '
		// ]]></script>';
	}

	echo '
	</div>';

	// The following will be used to let the user know that some AJAX process is running
	echo '
	<div id="ajax_in_progress" style="display: none;', $context['browser']['is_ie'] && !$context['browser']['is_ie7'] ? 'position: absolute;' : '', '">', $txt['ajax_in_progress'], '</div>';
	// TinyPortal
	if(!empty($settings['use_tp']) && $context['TPortal']['fixed_width']!=0)
		echo '</td></tr></table>';
	// end
	echo '</body></html>';
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree()
{
	global $context, $settings, $options;

	echo '<div class="nav" style="font-size: smaller; margin-bottom: 2ex; margin-top: 2ex;">';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" class="nav">' . $tree['name'] . '</a>' : $tree['name'], '</b>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo '&nbsp;>&nbsp;';
	}

	echo '</div>';
}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	// Work out where we currently are.
	$current_action = 'home';
	if (in_array($context['current_action'], array('admin', 'ban', 'boardrecount', 'cleanperms', 'detailedversion', 'dumpdb', 'featuresettings', 'featuresettings2', 'findmember', 'maintain', 'manageattachments', 'manageboards', 'managecalendar', 'managesearch', 'membergroups', 'modlog', 'news', 'optimizetables', 'packageget', 'packages', 'permissions', 'pgdownload', 'postsettings', 'regcenter', 'repairboards', 'reports', 'serversettings', 'serversettings2', 'smileys', 'viewErrorLog', 'viewmembers')))
		$current_action = 'admin';
	if (in_array($context['current_action'], array('search', 'admin', 'calendar', 'profile', 'mlist', 'register', 'login', 'help', 'pm', 'forum', 'tpadmin')))
		$current_action = $context['current_action'];
	if ($context['current_action'] == 'search2')
		$current_action = 'search';
	if (isset($_GET['dl']))
		$current_action = 'dlmanager';
	if (isset($_GET['board']) || isset($_GET['topic']))
		$current_action = 'forum';
	if ($context['current_action'] == 'theme')
		$current_action = isset($_REQUEST['sa']) && $_REQUEST['sa'] == 'pick' ? 'profile' : 'admin';

	// Are we using right-to-left orientation?
	if ($context['right_to_left'])
	{
		$first = 'last';
		$last = 'first';
	}
	else
	{
		$first = 'first';
		$last = 'last';
	}
	//button separator
	$separator = '&nbsp;';
	echo '
	<table cellpadding="0" cellspacing="0" border="0" style="margin-left: auto;margin-right: auto;">
		<tr>
			<td><a href="', $scripturl, '">' , $current_action == 'home' ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/h_home.gif" alt="' . $txt[103] . '" border="0" width="80" height="26" />' : '<img id="home" src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/home.gif" alt="' . $txt[103] . '" border="0" width="80" height="26" onmouseover="smfLangHighlight(this, true);" onmouseout="smfLangHighlight(this, false);" />' , '</a>', $separator ,'</td>';
	if (!empty($settings['use_tp']) && $settings['TPortal_front_type']!='boardindex')
		echo '
			<td><a href="', $scripturl, '?action=forum">' , $current_action == 'forum' ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/h_forum.gif" alt="' . $txt['forum'] . '" border="0" width="80" height="26" />' : '<img id="forum" src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/forum.gif" alt="' . $txt['forum'] . '" border="0" width="80" height="26" onmouseover="smfLangHighlight(this, true);" onmouseout="smfLangHighlight(this, false);" />' , '</a>', $separator ,'</td>';
		echo'
			<td><a href="', $scripturl, '?action=help">' , $current_action == 'help' ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/h_help.gif" alt="' . $txt[119] . '" border="0" width="80" height="26" />' : '<img id="help" src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/help.gif" alt="' . $txt[119] . '" border="0" width="80" height="26" onmouseover="smfLangHighlight(this, true);" onmouseout="smfLangHighlight(this, false);" />' , '</a>', $separator ,'</td>';
	// How about the [search] button?
	if ($context['allow_search'])
		echo '
			<td><a href="', $scripturl, '?action=search">' , $current_action == 'search' ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/h_search.gif" alt="' . $txt[182] . '" border="0" width="80" height="26" />' : '<img id="search" src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/search.gif" alt="' . $txt[182] . '" border="0" width="80" height="26" onmouseover="smfLangHighlight(this, true);" onmouseout="smfLangHighlight(this, false);" />' , '</a>', $separator ,'</td>';

	// Is the user allowed to administrate at all? ([admin])
	if ($context['allow_admin'])
		echo '
			<td><a href="', $scripturl, '?action=admin">' , $current_action == 'admin' ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/h_admin.gif" alt="' . $txt[2] . '" border="0" width="80" height="26" />' : '<img id="admin" src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/admin.gif" alt="' . $txt[2] . '" border="0" width="80" height="26" onmouseover="smfLangHighlight(this, true);" onmouseout="smfLangHighlight(this, false);" />' , '</a>', $separator ,'</td>';

	// Edit Profile... [profile]
	if ($context['allow_edit_profile'])
		echo '
			<td><a href="', $scripturl, '?action=profile">' , $current_action == 'profile' ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/h_profile.gif" alt="' . $txt[79] . '" border="0" width="80" height="26" />' : '<img id="profile" src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/profile.gif" alt="' . $txt[79] . '" border="0" width="80" height="26" onmouseover="smfLangHighlight(this, true);" onmouseout="smfLangHighlight(this, false);" />' , '</a>', $separator ,'</td>';

	// Go to PM center... [pm]
	if ($context['user']['is_logged'] && $context['allow_pm'])
		echo '
			<td><a href="', $scripturl, '?action=pm">' , $current_action == 'pm' ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/h_messages.gif" alt="' . $txt['pm_short'] . '" border="0" width="80" height="26" />' : '<img id="messages" src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/messages.gif" alt="' . $txt['pm_short'] . '" border="0" width="80" height="26" onmouseover="smfLangHighlight(this, true);" onmouseout="smfLangHighlight(this, false);" />' , '</a>', $separator ,'</td>';

	// The [calendar]!
	if ($context['allow_calendar'])
		echo '
			<td><a href="', $scripturl, '?action=calendar">' , $current_action == 'calendar' ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/h_calendar.gif" alt="' . $txt['calendar24'] . '" border="0" width="80" height="26" />' : '<img id="calendar" src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/calendar.gif" alt="' . $txt['calendar24'] . '" border="0" width="80" height="26" onmouseover="smfLangHighlight(this, true);" onmouseout="smfLangHighlight(this, false);" />' , '</a>', $separator ,'</td>';

	// the [member] list button
	if ($context['allow_memberlist'])
		echo '
			<td><a href="', $scripturl, '?action=mlist">' , $current_action == 'mlist' ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/h_memberlist.gif" alt="' . $txt[331] . '" border="0" width="80" height="26" />' : '<img id="memberlist" src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/memberlist.gif" alt="' . $txt[331] . '" border="0" width="80" height="26" onmouseover="smfLangHighlight(this, true);" onmouseout="smfLangHighlight(this, false);" />' , '</a>', $separator ,'</td>';

	// If the user is a guest, show [login] and [register] buttons.
	if ($context['user']['is_guest'])
	{
		echo '
			<td><a href="', $scripturl, '?action=login">' , $current_action == 'login' ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/h_login.gif" alt="' . $txt[34] . '" border="0" width="80" height="26" />' : '<img id="login" src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/login.gif" alt="' . $txt[34] . '" border="0" width="80" height="26" onmouseover="smfLangHighlight(this, true);" onmouseout="smfLangHighlight(this, false);" />' , '</a>', $separator ,'</td>
			<td><a href="', $scripturl, '?action=register">' , $current_action == 'register' ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/h_register.gif" alt="' . $txt[97] . '" border="0" width="80" height="26" />' : '<img id="register" src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/register.gif" alt="' . $txt[97] . '" border="0" width="80" height="26" onmouseover="smfLangHighlight(this, true);" onmouseout="smfLangHighlight(this, false);" />' , '</a>', $separator ,'</td>';
	}
	// Otherwise, they might want to [logout]...
	else
		echo '
			<td><a href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '">' , $current_action == 'logout' ? '<img src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/h_logout.gif" alt="' . $txt[108] . '" border="0" width="80" height="26" />' : '<img id="logout" src="' . $settings['images_url'] . '/' . $context['user']['language'] . '/logout.gif" alt="' . $txt[108] . '" border="0" width="80" height="26" onmouseover="smfLangHighlight(this, true);" onmouseout="smfLangHighlight(this, false);" />' , '</a>', $separator ,'</td>';
	// TinyPortal
	if(!empty($settings['use_tp']) && $context['TPortal']['leftbar'])
		echo '<td style="padding-left: 1ex;"><a href="javascript:void(0);" onclick="shrinkHeaderLeftbar(!current_leftbar); return false;"><img id="upshrinkLeftbar" src="', $settings['images_url'], '/', empty($options['collapse_leftbar']) ? 'upshrink.gif' : 'upshrink2.gif', '" alt="*" title="', $txt['upshrink_description'], '" style="margin: 2px 0;" border="0" /></a><img id="upshrinkTempLeftbar" src="', $settings['images_url'], '/blank.gif" alt="" style="margin-right: 0ex;" /></td>';
	if(!empty($settings['use_tp']) && $context['TPortal']['rightbar'])
		echo '<td style="padding-left: 1ex;"><a href="javascript:void(0);" onclick="shrinkHeaderRightbar(!current_rightbar); return false;"><img id="upshrinkRightbar" src="', $settings['images_url'], '/', empty($options['collapse_rightbar']) ? 'upshrink.gif' : 'upshrink2.gif', '" alt="*" title="', $txt['upshrink_description'], '" style="margin: 2px 0;" border="0" /></a><img id="upshrinkTempRightbar" src="', $settings['images_url'], '/blank.gif" alt="" style="margin-right: 0ex;" /></td>';
	// TinyPortal end
	//close the table
		echo '
		</tr>
	</table>';
}


// Generate a strip of buttons.
function template_button_strip($button_strip, $direction = 'top', $force_reset = false, $custom_td = '')
{
	global $settings, $buttons, $context, $txt, $scripturl;

	// Create the buttons...
	foreach ($button_strip as $key => $value)
	{
		if (isset($value['test']) && empty($context[$value['test']]))
		{
			unset($button_strip[$key]);
			continue;
		}
		elseif (!isset($buttons[$key]) || $force_reset)
			$buttons[$key] = '<a href="' . $value['url'] . '" ' .( isset($value['custom']) ? $value['custom'] : '') . '>' . ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . ($value['lang'] ? $context['user']['language'] . '/' : '') . $value['image'] . '" alt="' . $txt[$value['text']] . '" border="0" />' : $txt[$value['text']]) . '</a>';

		$button_strip[$key] = $buttons[$key];
	}

	if (empty($button_strip))
		return '<td>&nbsp;</td>';

	echo '
		<td ', $custom_td, '>', implode($context['menu_separator'], $button_strip) , '</td>';

}
function checkmods()
{
	global $context, $settings, $options, $scripturl, $txt;

	if($context['user']['is_admin'])
	{
		$error='';
		// TP 
		if(!empty($settings['use_tp']) && !isset($context['TPortal']['showtop']))
			$error .= '<div class="errorbar">' . $txt['tp_error'] . '</div>';

		// render it
		if(!empty($error))
			echo '<div id="errorpanel">'.$error.'</div>';
	}
}
?>